<?php

namespace Noalyss\Copy_Parameter;

/*
 *   This file is part of NOALYSS.
 *
 *   NOALYSS is free software; you can redistribute it and/or modify
 *   it under the terms of the GNU General Public License as published by
 *   the Free Software Foundation; either version 2 of the License, or
 *   (at your option) any later version.
 *
 *   NOALYSS is distributed in the hope that it will be useful,
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *   GNU General Public License for more details.
 *
 *   You should have received a copy of the GNU General Public License
 *   along with NOALYSS; if not, write to the Free Software
 *   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */
// Copyright Author Dany De Bontridder danydb@aevalys.eu 22/10/23
global $g_dir_copy_param;
require_once $g_dir_copy_param . "/class/Copy_Parameter.php";

/**
 * @file
 * @brief  Manage the import - export VAT
 */
class Analytic extends Copy_Parameter {

    function __construct() {
        
    }

    /**
     * @brief load the files and display its content. Let you approve before changing in the DB
     * @return int 0 = OK, 1= no file given, 2=error cannot upload the file, 3 content of the file is not a valid JSON
     */
    #[\Override]
    public function display_content($file_name) {
        global $g_dir_copy_param;
        $aParam = array();
        $id = $this->load_file($file_name, $aParam);
        if ( $id < 0) { return $id; }
        require_once $g_dir_copy_param . "/template/Analytic-display.php";
        return $id;
    }
    /**
     * 
     * @param $a_row (array of assoc array)
     * @param $table (string) name of the table
     */
    private function insert_row($a_row,$table)
    {
        global $cn;
        $nb_row = count($a_row);
        $sql="";$n=0;
        for ( $i = 0; $i < $nb_row;$i++)
        {
            if ( $sql == "") {
                $sql = "insert into {$table}  (";
                $sep = "";$f=1;$c=$d="";
                foreach ($a_row[$i] as $key=>$value) {
                    $c.= $sep." ".$key;
                    $d.= $sep."\$$f";
                    $f++;$sep=",";
                }
                $sql .= $c.") values (".$d.")";
                
            }
            $cn->exec_sql($sql,$a_row[$i]);
        }
       return $i;
    }
    /**
     * \brief  Receive a file to import , this file will replace the current configuration
     * \return int 0 = OK , 2 : no file given , 3 : file invalid , 4 others errors
     */
    #[\Override]
    public function import($file_id) {
        try {
            global $cn;
            if ( $cn->get_value("select count(oa_id) from operation_analytique") > 0)
            {
                throw new \Exception("Opération analytique existante");
            }
            $object_json = $this->load_json($file_id);
            /**
             * @var $object_json (array) key = accounting (array) , tva_rate(array) , version (int)
             */
            $object_json = $this->load_json($file_id);
            if (    ! isset ($object_json['version'])
                    || ! isset($object_json['axis_anl'])
                    || ! isset($object_json['accounting_anl'])
                    || ! isset ($object_json['group_anl']))
            {
                throw new \Exception("JSON Invalide ");
            }
            if ( $object_json['version'] != 1 ) {
                throw new \Exception("Version non supportée  {$object_json['version'] }");
            }
            $cn->start();
            $cn->exec_sql('delete from groupe_analytique');
            $cn->exec_sql('delete from key_distribution_detail');
            $cn->exec_sql('delete from key_distribution_ledger');
            $cn->exec_sql('delete from key_distribution_activity');
            $cn->exec_sql('delete from key_distribution');
            $cn->exec_sql('delete from poste_analytique');
            $cn->exec_sql('delete from plan_analytique');
            
            // insert plan analytique
          $this->insert_row($object_json['axis_anl'],"plan_analytique");
          $cn->alter_seq("plan_analytique_pa_id_seq",$cn->get_value("select 1+max(pa_id) from plan_analytique"));
          
          $this->insert_row($object_json['accounting_anl'],"poste_analytique");
          $cn->alter_seq("poste_analytique_po_id_seq",$cn->get_value('select 1+max(po_id) from poste_analytique'));
          
          $this->insert_row($object_json['group_anl'],"groupe_analytique");
          
          $this->insert_row($object_json['key_distribution'],"key_distribution");
          $cn->alter_seq("key_distribution_kd_id_seq",$cn->get_value('select 1+max(kd_id) from key_distribution'));
          
          $this->insert_row($object_json['key_distribution_detail'],"key_distribution_detail");
          $cn->alter_seq("key_distribution_detail_ke_id_seq",$cn->get_value('select 1+max(ke_id) from key_distribution_detail'));
          
          $this->insert_row($object_json['key_distribution_activity'],"key_distribution_activity");
          $cn->alter_seq("key_distribution_activity_ka_id_seq",$cn->get_value('select 1+max(ka_id) from key_distribution_activity'));
          
          $this->insert_row($object_json['key_distribution_ledger'],"key_distribution_ledger");
          $cn->alter_seq("key_distribution_ledger_kl_id_seq",$cn->get_value('select 1+max(kl_id) from key_distribution_ledger'));
          
          // rest sequence
          
          
            $cn->commit();
           echo '<div class="copa-success">';
           echo ("Configuration comptabilité analytique importée : plan, poste, groupe et clef ");
            echo '</div>';
        } catch (\Exception $exc) {
            echo_warning(_(" Importation TVA a échoué, aucun changement "));
            $cn->rollback();
           throw new \Exception("ANL143".$exc->getMessage(), 1, $exc);
        }
    }
}
