<?php

namespace Noalyss\Copy_Parameter;

/*
 *   This file is part of NOALYSS.
 *
 *   NOALYSS is free software; you can redistribute it and/or modify
 *   it under the terms of the GNU General Public License as published by
 *   the Free Software Foundation; either version 2 of the License, or
 *   (at your option) any later version.
 *
 *   NOALYSS is distributed in the hope that it will be useful,
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *   GNU General Public License for more details.
 *
 *   You should have received a copy of the GNU General Public License
 *   along with NOALYSS; if not, write to the Free Software
 *   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */
// Copyright Author Dany De Bontridder danydb@aevalys.eu 22/10/23

/**
 * @file
 * @brief Abstract class for the module
 */
abstract class Copy_Parameter {

    public function load_file($filename, &$aParam) {
        global $cn, $g_dir_copy_param;
        // nothing to save
        if ($_FILES[$filename]['error'] != 0) {
            // echo_warning("IT0: Erreur de chargement du fichier");
            return -1;
        }

        // upload file, will be saved and send in POST
        $file_uploaded = tempnam($_ENV['TMP'], 'copa_file');

        if (move_uploaded_file($_FILES[$filename]['tmp_name'], $file_uploaded) == false) {
            // echo_warning("IT1: Echec téléchargement du fichier");
            return -2;
        }

        // read content
        // $hdl_read handle to the uploaded file
        $hdl_read = fopen($file_uploaded, "r");

        // $content string content of the uploaded file
        $content = fread($hdl_read, filesize($file_uploaded));

        // if content is not a valid JSON stop
        $aParam = json_decode($content, true);
        if ($aParam == null) {
            //echo_warning(_('Fichier invalide'));
            return -3;
        }
        // save object in table
        $id = $cn->get_value('insert into copy_parameter.temp_object(t_json) values ($1) returning  id', [$content]);
        return $id;
    }

    /**
     * @brief load the files and display its content. Let you approve before changing in the DB
     * @return int 0 = OK, 1= no file given, 2=error cannot upload the file, 3 content of the file is not a valid JSON
     */
    abstract function display_content($filename);

    /**
     * \brief  Receive a file to import , this file will replace the current configuration
     * \return int 0 = OK , 2 : no file given , 3 : file invalid , 4 others errors
     */
    abstract function import($file_id);

    /**
     * @brief display a warning it display_content doesn't return an int >0
     * @param $ret  (int) result from display_content()

     */
    public function display_warning($ret) {
        if ($ret == -1) {
            echo_warning("CP0: Erreur de chargement du fichier");
        } elseif ($ret == -2) {
            echo_warning("CP1: Echec téléchargement du fichier");
        } elseif ($ret == -3) {
            echo_warning("CP2: Fichier invalide");
        } elseif ($ret > 0) {
            return;
        }
        // return code unknown
        throw new \Exception(" CP80: ret = [$ret]");
    }

    /**
     * @brief load the JSON from database and turn it into an associative array
     * @global Database $cn
     * @param $file_id (int) the TEMP_OBJET.ID column (DB)
     * @return array
     * @throws \Exception if the json cannot be fetched from DB
     */
    public function load_json($file_id) {
        global $cn;
        $http = new \HttpInput();
        $json = $cn->get_value("select t_json from copy_parameter.temp_object where id=$1", [$file_id]);
        if ($json == "") {
            echo_warning("Entrée invalide");
            return;
        }
        $object_json = json_decode($json, true);
        if ($object_json == null) {
            throw new \Exception("Object invalide");
        }
        return $object_json;
    }

    /**
     * @brief display the content of  $a_data 
     * @param $title (string): title of the data
     * @param$a_header (assoc. array) : associative array col_name => header to display
     * @param $a_data (array of assoc.array ): array of row , row is an array : column => value
     */
    protected function display_table($title, $a_header, $a_data) {
        global $g_dir_copy_param;
        require $g_dir_copy_param . '/template/Copy_Parameter-display_table.php';
    }
}
