<?php

namespace Noalyss\Copy_Parameter;

/*
 *   This file is part of NOALYSS.
 *
 *   NOALYSS is free software; you can redistribute it and/or modify
 *   it under the terms of the GNU General Public License as published by
 *   the Free Software Foundation; either version 2 of the License, or
 *   (at your option) any later version.
 *
 *   NOALYSS is distributed in the hope that it will be useful,
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *   GNU General Public License for more details.
 *
 *   You should have received a copy of the GNU General Public License
 *   along with NOALYSS; if not, write to the Free Software
 *   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */
// Copyright Author Dany De Bontridder danydb@aevalys.eu 22/10/23
require_once $g_dir_copy_param."/class/Copy_Parameter.php";
/**
 * @file
 * @brief Manage the import - export VAT
 */
class VAT  extends Copy_Parameter
{

    function __construct() {
        
    }

    /**
     * @brief load the files and display its content. Let you approve before changing in the DB
     * @return int 0 = OK, 1= no file given, 2=error cannot upload the file, 3 content of the file is not a valid JSON
     */
    function display_content($file_name): int {
        global $g_dir_copy_param;
        $aParam = array();
        $id = $this->load_file($file_name,$aParam);
        if ( $id < 0) { return $id; }
        require_once $g_dir_copy_param . "/template/Tva-display.php";
        return $id;
    }

    /**
     * \brief  Receive a file to import , this file will replace the current configuration,
     * the unused VAT will be removed, the vat with same code or the same id won't be inserted
     * \return int 0 = OK , 2 : no file given , 3 : file invalid , 4 others errors
     */
    function import($file_id) {
        global $cn;
        $http=new \HttpInput();
        try {
            /**
             * var $warning (array) to store warning for VAT not inserted, there
             * is no updaye
             */
            $warning=array();
            /**
             * @var $object_json (array) key = accounting (array) , tva_rate(array) , version (int)
             */
            $object_json = $this->load_json($file_id);
            if (    ! isset ($object_json['version'])
                    || ! isset($object_json['accounting'])
                    || ! isset ($object_json['tva_rate']))
            {
                throw new \Exception("JSON Invalide ");
            }
            if ( $object_json['version'] != "1" ) {
              //  var_dump($object_json);
                throw new \Exception("Version non supportée  {$object_json['version'] }");
            }
            $cn->start();

            // insert or update accounting
            $nb_accounting = count($object_json['accounting']);
            for ($i = 0; $i < $nb_accounting; $i++) {
                $tmp = new \Tmp_Pcmn_SQL($cn);
                $id = $cn->get_value("select id from tmp_pcmn where upper(pcm_val)=upper(trim($1))", [$object_json['accounting'][$i]['pcm_val']]);
                if ($id != "") {
                    $tmp->id = $id;
                    $tmp->load();
                }
                $tmp->pcm_val = $object_json['accounting'][$i]['pcm_val'];
                $tmp->pcm_lib = $object_json['accounting'][$i]['pcm_lib'];
                $tmp->pcm_val_parent = $object_json['accounting'][$i]['pcm_val_parent'];
                $tmp->pcm_type = $object_json['accounting'][$i]['pcm_type'];
                $tmp->pcm_direct_use = $object_json['accounting'][$i]['pcm_direct_use'];
                $tmp->save();
            }
            // delete existing unused VAT
            if ($http->request("remove_unused_vat", "number", 0) == 1) {
                $cn->exec_sql("
                    delete from tva_rate 
                    where 
                        tva_id not in (select qs_vat_code from quant_sold)
                        and tva_id not in (select qp_vat_code from quant_purchase)");
            }
            // insert VAT
            $nb_tva_rate = count($object_json['tva_rate']);
            for ($i = 0; $i < $nb_tva_rate; $i++) {
                $tva = new \Tva_Rate_SQL($cn);
                $id = $cn->get_value("select tva_id from tva_rate where tva_code=$1",
                        [$object_json['tva_rate'][$i]['tva_code']]);
                if ($id == "") {
                     $id = $object_json['tva_rate'][$i]['tva_id'];
                }else {
                      $warning[]=sprintf("CODE TVA [%s] existe déjà code : %s id : %s"
                            , $object_json['tva_rate'][$i]['tva_code']
                            , $object_json['tva_rate'][$i]['tva_code']
                            , $object_json['tva_rate'][$i]['tva_id']  );
                      continue;
                }
                // we don't insert data or update existing (and used) VAT,
                if ( $cn->get_value("select count(tva_id) from tva_rate where tva_id=$1",
                        [$id]) > 0) {
                    $warning[]=sprintf("TVA ID [%s] existe code déjà code : %s id : %s"
                            , $object_json['tva_rate'][$i]['tva_id']
                            , $object_json['tva_rate'][$i]['tva_code']
                            , $object_json['tva_rate'][$i]['tva_id']  );
                    continue;
                }
                $tva->tva_id = $id;
                $tva->tva_label = $object_json['tva_rate'][$i]['tva_label'];
                $tva->tva_rate = $object_json['tva_rate'][$i]['tva_rate'];
                $tva->tva_comment = $object_json['tva_rate'][$i]['tva_comment'];
                $tva->tva_poste = $object_json['tva_rate'][$i]['tva_poste'];
                $tva->tva_both_side = $object_json['tva_rate'][$i]['tva_both_side'];
                $tva->tva_payment_sale = $object_json['tva_rate'][$i]['tva_payment_sale'];
                $tva->tva_payment_purchase = $object_json['tva_rate'][$i]['tva_payment_purchase'];
                $tva->tva_code = $object_json['tva_rate'][$i]['tva_code'];
                $tva->tva_reverse_account = $object_json['tva_rate'][$i]['tva_reverse_account'];
                $tva->insert();
            }
            // commit
            $cn->commit();
            //echo '<div style="width:50rem">';
            
            $nb_warning=count($warning);
            if ( $nb_warning == 0) {
                echo '<div class="copa-success">';
                printf ("TVA et poste comptable Importés %s",$nb_warning);
                echo '</div>';
            } else {
                echo '<div class="copa-warning">';
                printf ("TVA et poste comptable Importés %s",$nb_warning);
                echo h2("Non importés");
                echo '<ol>';
                for ($e=0;$e<$nb_warning;$e++) {
                    echo '<li>';
                    echo $warning[$e];
                    echo '</li>';
                }
                echo '</ol>';
                echo '</div>';
            }
            //echo '</div>';
        } catch (\Exception $exc) {
            echo_warning(_(" Importation TVA a échoué, aucun changement "));
            $cn->rollback();
            throw new \Exception("VAT164".$exc->getMessage(), 1, $exc);
        }

    }
}
