<?php
/*
 *   This file is part of NOALYSS.
 *
 *   NOALYSS is free software; you can redistribute it and/or modify
 *   it under the terms of the GNU General Public License as published by
 *   the Free Software Foundation; either version 2 of the License, or
 *   (at your option) any later version.
 *
 *   NOALYSS is distributed in the hope that it will be useful,
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *   GNU General Public License for more details.
 *
 *   You should have received a copy of the GNU General Public License
 *   along with NOALYSS; if not, write to the Free Software
 *   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*/
/* $Revision$ */

// Copyright (c) 2024 Author Dany De Bontridder dany@alchimerys.be

/*!
 * \file
 * \brief main file for importing or exporting accountancy
 */

/*
 * load javascript
 */
if ( ! defined ('ALLOWED') ) die('Appel direct ne sont pas permis');

global $version_plugin,$g_dir_copy_param;
global $cn;

$http = new HttpInput();
/**
 * @var $url (string) url parameter
 */
$url= http_build_query(["gDossier"=>$http->request('gDossier'),
    "ac"=>$http->request('ac'),
    "plugin_code"=>$http->request("plugin_code","string","COPA")
    ]);

/**
 * @var $g_dir_copy_param string : global param. dir of the plugin
 * @var $version_plugin int inherited from index.php
 * @var $tab string show the tab from the last request, inherited from index.php
 */

$g_dir_copy_param=__DIR__;

$version_plugin = \Extension::get_version($g_dir_copy_param . "/plugin.xml", $http->request("ac"));

Extension::check_version(9300);

// install plugin
if ( $cn->exist_schema("copy_parameter") == false ) {
    require_once __DIR__."/class/Install/install_plugin.class.php";
    $install_plugin= new  \Noalyss\Copy_Parameter\Install\Install_Plugin($cn);
    $install_plugin->install();
}
?>
<style>
    div.copa-success {
        width: min(50%,60rem);
        background-color : lightgreen;
        color:green;
        padding :2ch;
        border:1px solid green;
        border-radius:7px;
        margin-left:min(25%,20rem);
    }
    
    .copa-warning {
      background-color: hsla(38.8, 100%, 50%, 0.33);
      color: orangered;
      text-align: center;
      padding:0.5rem;
      border-radius: 7px;
       padding :2ch;
        font-weight: bold;
      width: min(50%,60rem);
     margin-left:min(25%,20rem);
      margin-top: 2rem;
    }
    .copa-warning ol {
      text-align: left;
    }
    .copa-warning h2 {
        text-align: left;
        margin-left:30px;
        margin-left:3ch;
        font-size:120%;
        background-color:transparent;
        color:orangered;
        font-style: normal;
    }
    
    </style>

<?php


echo '<a  id="help"href="http://wiki.noalyss.eu/doku.php?id=copy_param" target="_blank">Aide</a>' .
    '<span style="font-size:0.8em;color:red;display:inline">vers:' . $version_plugin . '</span>';

$tab=$http->request('tab','string','vat_manage');

$main = new Output_Html_Tab();


// Import - Export VAT
$tab_vat = new Html_Tab('vat_manage', _('TVA'));

ob_start();

require __DIR__."/include/tva.inc.php";


$tab_vat->set_content(ob_get_contents());
ob_end_clean();

$main->add($tab_vat);

// Import Export Accounting

// import export analytic

// import - export attribute
$tab_anl = new Html_Tab('anl_manage', _('Analytique'));
ob_start();

require __DIR__."/include/axis-analytic.inc.php";


$tab_anl->set_content(ob_get_contents());
ob_end_clean();

$main->add($tab_anl);
// import - export category
$main->output();
?>
<script>
    <?=$main->build_js($tab)?>
</script>


